@@ -23,9 +23,15 @@
 
 #include "stream.h"
 
+typedef uint8_t Byte;
+typedef uint32_t Dword;
+typedef uint64_t Qword;
+
+#define DWORD_ERR ((Dword) -1)
+
 /*extern int ConnectToFloppyd(const char* name, Class_t** ioclass);*/
 Stream_t *FloppydOpen(struct device *dev, 
-		      char *name, int mode, char *errmsg,
+		      const char *name, int mode, char *errmsg,
 		      mt_size_t *maxSize);
 
 #define FLOPPYD_DEFAULT_PORT 5703
@@ -59,7 +65,23 @@ enum AuthErrorsEnum {
 	AUTH_IO_ERROR
 };
 
-typedef unsigned long IPaddr_t;
+
+UNUSED(static inline void cork(int sockhandle, int on))
+{
+#ifdef TCP_CORK
+	if(setsockopt(sockhandle, IPPROTO_TCP, 
+		      TCP_CORK, (char *)&on, sizeof(on)) < 0) {
+		perror("setsockopt cork");
+	}
+#else
+	on = 1 ^ on;
+	if(setsockopt(sockhandle, IPPROTO_TCP, 
+		      TCP_NODELAY, (char *)&on, sizeof(on)) < 0) {
+		perror("setsockopt nodelay");
+	}
+#endif
+}
+
 
 #endif
 #endif
