@@ -18,10 +18,10 @@
 #include "sysincludes.h"
 #include "msdos.h"
 
-const char *mversion="4.0.25";
+const char *mversion="4.0.31";
 
 /* Multiple releases on same day should be marked with (b), (cd), (d) after
  * date string below */
-const char *mdate = "October 24th, 2020";
+const char *mdate = "June 19th, 2021";
 
-const char *mformat_banner = "MTOO4025";
+const char *mformat_banner = "MTOO4031";
